==> bookmark-links-0.1.3.tgz: package/src/index.ts <==
import { generateUrlFile, importUrlFile } from "./common/util";
import { JSDOM } from "jsdom";
import { program } from "commander";
import path from "path";
import fs from "fs";

function initProgram() {
  program
    .description("Convert html bookmark links to .url format files.")
    .option("-i, --input <input>", "input file path", "./bookmarks.html")
    .option("-o, --output <output>", "output directory path", "./bookmarks/");

  program.parse();
  return program.opts<{
    input: string;
    output: string;
  }>();
}

export function sample() {
  console.log("sample function");
}

export async function main() {
  const options = initProgram();
  console.log("Converting html bookmark links to .url format files");

  const data = await importUrlFile(options.input);
  const aTagList = new JSDOM(data).window.document.getElementsByTagName("A");

  const outputPath = path.join("./", options.output, "/");
  if (fs.existsSync(outputPath))
    throw new Error(
      "Output directory already exists. Please delete it manually.",
    );
  await fs.promises.mkdir(outputPath);

  for (let i = 0; i < aTagList.length; i++) {
    let title = aTagList.item(i)?.textContent ?? "";

    // replace specific characters with "_"
    ["\\", "/", ":", "*", "?", "<", ">", "|", " ", "　"].map(
      mark => (title = title.replaceAll(mark, "_")),
    );

    const href = aTagList.item(i)?.getAttribute("href");
    if (!href) console.error(`DOM error on ${title}`);
    await generateUrlFile(outputPath, `${title}.url`, href ?? "");
  }
}

==> bookmark-links-1.1.0.tgz: package/src/index.ts <==
import { program } from "commander";
import fs from "fs";
import { JSDOM } from "jsdom";
import path from "path";
import { generateUrlFile, importUrlFile } from "./common/util";

function initProgram() {
  program
    .description("Convert html bookmark links to .url format files.")
    .option("-i, --input <input>", "input file path", "./bookmarks.html")
    .option("-o, --output <output>", "output directory path", "./bookmarks/");

  program.parse();
  return program.opts<{
    input: string;
    output: string;
  }>();
}

export async function generate() {
  const options = initProgram();
  console.log("Converting html bookmark links to .url format files");

  const outputPath = path.join("./", options.output, "/");
  if (fs.existsSync(outputPath)) {
    throw new Error(
      "Output directory already exists. Please delete it manually.",
    );
  }
  await fs.promises.mkdir(outputPath);

  const data = new JSDOM(await importUrlFile(options.input));
  const aTagList = data.window.document.getElementsByTagName("A");

  for (let i = 0; i < aTagList.length; i++) {
    let title = aTagList.item(i)?.textContent ?? "";

    // replace specific characters with "_"
    ["\\", "/", ":", "*", "?", "<", ">", "|", " ", "　", "\"", "'", "`"].map(
      mark => (title = title.replaceAll(mark, "_")),
    );

    const href = aTagList.item(i)?.getAttribute("href");
    if (!href) console.error(`DOM error on ${title}`);
    await generateUrlFile(outputPath, `${title}.url`, href ?? "");
  }
}
